@@ -47,10 +47,8 @@
 #include <KCalCore/OccurrenceIterator>
 
 #include <KIconLoader> // for SmallIcon()
-#include <KHBox>
 #include <KMessageBox>
 #include <KServiceTypeTrader>
-#include <KVBox>
 #include <KWordWrap>
 
 #include <QApplication>
@@ -209,12 +207,12 @@ public:
     QGridLayout *mGridLayout;
     QFrame *mTopDayLabels;
     QBoxLayout *mLayoutTopDayLabels;
-    KHBox *mTopDayLabelsFrame;
+    QFrame *mTopDayLabelsFrame;
     QList<AlternateLabel *> mDateDayLabels;
     QBoxLayout *mLayoutBottomDayLabels;
     QFrame *mBottomDayLabels;
-    KHBox *mBottomDayLabelsFrame;
-    KHBox *mAllDayFrame;
+    QFrame *mBottomDayLabelsFrame;
+    QFrame *mAllDayFrame;
     QWidget *mTimeBarHeaderFrame;
     QSplitter *mSplitterAgenda;
     QList<QLabel *> mTimeBarHeaders;
@@ -295,6 +293,9 @@ protected:
     void calendarIncidenceAdded(const KCalCore::Incidence::Ptr &incidence) Q_DECL_OVERRIDE;
     void calendarIncidenceChanged(const KCalCore::Incidence::Ptr &incidence) Q_DECL_OVERRIDE;
     void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence, const KCalCore::Calendar *calendar) Q_DECL_OVERRIDE;
+private:
+    //quiet --overloaded-virtual warning
+    using KCalCore::Calendar::CalendarObserver::calendarIncidenceDeleted;
 };
 
 bool AgendaView::Private::datesEqual(const KCalCore::Incidence::Ptr &one, const KCalCore::Incidence::Ptr &two) const
@@ -736,22 +737,31 @@ void AgendaView::init(const QDate &start, const QDate &end)
     d->mGridLayout->addWidget(d->mSplitterAgenda, 1, 0);
 
     /* Create day name labels for agenda columns */
-    d->mTopDayLabelsFrame = new KHBox(d->mSplitterAgenda);
-    d->mTopDayLabelsFrame->setSpacing(SPACING);
+    d->mTopDayLabelsFrame = new QFrame(d->mSplitterAgenda);
+    auto layout = new QHBoxLayout(d->mTopDayLabelsFrame);
+    layout->setMargin(0);
+    layout->setSpacing(SPACING);
 
     /* Create all-day agenda widget */
-    d->mAllDayFrame = new KHBox(d->mSplitterAgenda);
-    d->mAllDayFrame->setSpacing(SPACING);
+    d->mAllDayFrame = new QFrame(d->mSplitterAgenda);
+    auto allDayFrameLayout = new QHBoxLayout(d->mAllDayFrame);
+    allDayFrameLayout->setMargin(0);
+    allDayFrameLayout->setSpacing(SPACING);
 
     // Alignment and description widgets
     if (!d->mIsSideBySide) {
-        d->mTimeBarHeaderFrame = new KHBox(d->mAllDayFrame);
+        d->mTimeBarHeaderFrame = new QFrame(d->mAllDayFrame);
+        allDayFrameLayout->addWidget(d->mTimeBarHeaderFrame);
+        auto timeBarHeaderFrameLayout = new QHBoxLayout(d->mTimeBarHeaderFrame);
+        timeBarHeaderFrameLayout->setMargin(0);
+        timeBarHeaderFrameLayout->setSpacing(0);
         d->mDummyAllDayLeft = new QWidget(d->mAllDayFrame);
+        allDayFrameLayout->addWidget(d->mDummyAllDayLeft);
     }
 
     // The widget itself
-    AgendaScrollArea *allDayScrollArea = new AgendaScrollArea(true, this,
-            d->mIsInteractive, d->mAllDayFrame);
+    AgendaScrollArea *allDayScrollArea = new AgendaScrollArea(true, this, d->mIsInteractive, d->mAllDayFrame);
+    allDayFrameLayout->addWidget(allDayScrollArea);
     d->mAllDayAgenda = allDayScrollArea->agenda();
 
     /* Create the main agenda widget and the related widgets */
@@ -795,8 +805,10 @@ void AgendaView::init(const QDate &start, const QDate &end)
     }
 
     /* Create a frame at the bottom which may be used by decorations */
-    d->mBottomDayLabelsFrame = new KHBox(d->mSplitterAgenda);
-    d->mBottomDayLabelsFrame->setSpacing(SPACING);
+    d->mBottomDayLabelsFrame = new QFrame(d->mSplitterAgenda);
+    layout = new QHBoxLayout(d->mBottomDayLabelsFrame);
+    layout->setMargin(0);
+    layout->setSpacing(SPACING);
 
     if (!d->mIsSideBySide) {
         /* Make the all-day and normal agendas line up with each other */
@@ -1121,6 +1133,7 @@ void AgendaView::placeDecorations(DecorationList &decoList, const QDate &date,
         elements = forWeek ? deco->weekElements(date) : deco->dayElements(date);
         if (elements.count() > 0) {
             auto decoHBox = new QFrame(labelBox);
+            labelBox->layout()->addWidget(decoHBox);
             auto layout = new QHBoxLayout(decoHBox);
             layout->setSpacing(0);
             layout->setMargin(0);
@@ -1155,7 +1168,8 @@ void AgendaView::createDayLabels(bool force)
     QFontMetrics fm = fontMetrics();
 
     d->mTopDayLabels = new QFrame(d->mTopDayLabelsFrame);
-    d->mTopDayLabelsFrame->setStretchFactor(d->mTopDayLabels, 1);
+    d->mTopDayLabelsFrame->layout()->addWidget(d->mTopDayLabels);
+    static_cast<QBoxLayout*>(d->mTopDayLabelsFrame->layout())->setStretchFactor(d->mTopDayLabels, 1);
     d->mLayoutTopDayLabels = new QHBoxLayout(d->mTopDayLabels);
     d->mLayoutTopDayLabels->setMargin(0);
     d->mLayoutTopDayLabels->setSpacing(1);
@@ -1168,17 +1182,24 @@ void AgendaView::createDayLabels(bool force)
                         1, QSizePolicy::Fixed);
 
     d->mLayoutTopDayLabels->addSpacerItem(spacer);
-    KVBox *topWeekLabelBox = new KVBox(d->mTopDayLabels);
+    auto topWeekLabelBox = new QFrame(d->mTopDayLabels);
+    auto topWeekLabelBoxLayout = new QVBoxLayout(topWeekLabelBox);
+    topWeekLabelBoxLayout->setMargin(0);
+    topWeekLabelBoxLayout->setSpacing(0);
     d->mLayoutTopDayLabels->addWidget(topWeekLabelBox);
     if (d->mIsSideBySide) {
         topWeekLabelBox->hide();
     }
 
     d->mBottomDayLabels = new QFrame(d->mBottomDayLabelsFrame);
-    d->mBottomDayLabelsFrame->setStretchFactor(d->mBottomDayLabels, 1);
+    d->mBottomDayLabelsFrame->layout()->addWidget(d->mBottomDayLabels);
+    static_cast<QBoxLayout*>(d->mBottomDayLabelsFrame->layout())->setStretchFactor(d->mBottomDayLabels, 1);
     d->mLayoutBottomDayLabels = new QHBoxLayout(d->mBottomDayLabels);
     d->mLayoutBottomDayLabels->setMargin(0);
-    KVBox *bottomWeekLabelBox = new KVBox(d->mBottomDayLabels);
+    auto bottomWeekLabelBox = new QFrame(d->mBottomDayLabels);
+    auto bottomWeekLabelBoxLayout = new QVBoxLayout(bottomWeekLabelBox);
+    bottomWeekLabelBoxLayout->setMargin(0);
+    bottomWeekLabelBoxLayout->setSpacing(0);
     d->mLayoutBottomDayLabels->addWidget(bottomWeekLabelBox);
 
 #ifndef EVENTVIEWS_NODECOS
@@ -1193,9 +1214,15 @@ void AgendaView::createDayLabels(bool force)
 #endif
 
     Q_FOREACH (const QDate &date, d->mSelectedDates) {
-        KVBox *topDayLabelBox = new KVBox(d->mTopDayLabels);
+        auto topDayLabelBox = new QFrame(d->mTopDayLabels);
+        auto topDayLabelBoxLayout = new QVBoxLayout(topDayLabelBox);
+        topDayLabelBoxLayout->setMargin(0);
+        topDayLabelBoxLayout->setSpacing(0);
         d->mLayoutTopDayLabels->addWidget(topDayLabelBox);
-        KVBox *bottomDayLabelBox = new KVBox(d->mBottomDayLabels);
+        auto bottomDayLabelBox = new QFrame(d->mBottomDayLabels);
+        auto bottomDayLabelBoxLayout = new QVBoxLayout(bottomDayLabelBox);
+        bottomDayLabelBoxLayout->setMargin(0);
+        bottomDayLabelBoxLayout->setSpacing(0);
         d->mLayoutBottomDayLabels->addWidget(bottomDayLabelBox);
 
         int dW = date.dayOfWeek();
@@ -1205,8 +1232,8 @@ void AgendaView::createDayLabels(bool force)
                                 date.day());
         QString shortstr = QString::number(date.day());
 
-        AlternateLabel *dayLabel =
-            new AlternateLabel(shortstr, longstr, veryLongStr, topDayLabelBox);
+        AlternateLabel *dayLabel = new AlternateLabel(shortstr, longstr, veryLongStr, topDayLabelBox);
+        topDayLabelBoxLayout->addWidget(dayLabel);
         dayLabel->useShortText(); // will be recalculated in updateDayLabelSizes() anyway
         dayLabel->setAlignment(Qt::AlignHCenter);
         if (date == QDate::currentDate()) {
@@ -1220,8 +1247,8 @@ void AgendaView::createDayLabels(bool force)
         Q_FOREACH (const QString &text, texts) {
             // Compute a small version of the holiday string for AlternateLabel
             const KWordWrap ww = KWordWrap::formatText(fm, topDayLabelBox->rect(), 0, text, -1);
-            AlternateLabel *label =
-                new AlternateLabel(ww.truncatedString(), text, text, topDayLabelBox);
+            AlternateLabel *label = new AlternateLabel(ww.truncatedString(), text, text, topDayLabelBox);
+            topDayLabelBoxLayout->addWidget(label);
             label->setAlignment(Qt::AlignCenter);
         }
 
@@ -1399,6 +1426,7 @@ void AgendaView::createTimeBarHeaders()
         TimeLabels *timeLabel = static_cast<TimeLabels *>(area->widget());
         QLabel *label = new QLabel(timeLabel->header().replace(QLatin1Char('/'), QStringLiteral("/ ")),
                                    d->mTimeBarHeaderFrame);
+        d->mTimeBarHeaderFrame->layout()->addWidget(label);
         label->setFont(labelFont);
         label->setAlignment(Qt::AlignBottom | Qt::AlignRight);
         label->setMargin(0);
